/*****************************************************************************
 *   Copyright (C) 2008 Thomas Kaiser, thomas@ft-fanpage.de                  *
 *   Copyright (C) 2009 Peter "woggle" Mack, mac@denich.net                  *
 *   Copyright (C) 2011 Christian "Cebra" Brandtner, brandtner@brandtner.net *
 *   Copyright (C) 2011 Harald Bongartz                                      *
 *                                                                           *
 *   This program is free software; you can redistribute it and/or modify    *
 *   it under the terms of the GNU General Public License as published by    *
 *   the Free Software Foundation; either version 2 of the License.          *
 *                                                                           *
 *   This program is distributed in the hope that it will be useful,         *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 *   GNU General Public License for more details.                            *
 *                                                                           *
 *   You should have received a copy of the GNU General Public License       *
 *   along with this program; if not, write to the                           *
 *   Free Software Foundation, Inc.,                                         *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.               *
 *                                                                           *
 *                                                                           *
 *   Credits to:                                                             *
 *   Holger Buss & Ingo Busker from mikrokopter.de for the MK project + SVN  *
 *                          http://www.mikrokopter.de                        *
 *   Gregor "killagreg" Stobrawa for his version of the MK code              *
 *   Thomas Kaiser "thkais" for the original project. See                    *
 *                          http://www.ft-fanpage.de/mikrokopter/            *
 *                          http://forum.mikrokopter.de/topic-4061-1.html    *
 *   Claas Anders "CaScAdE" Rathje for providing the font and his C-OSD code *
 *                          http://www.mylifesucks.de/oss/c-osd/             *
 *   Harald Bongartz "HaraldB" for providing his Ideas and Code for usibility*
 *****************************************************************************/


#ifndef HAL_HW3_9_C_
#define HAL_HW3_9_C_

#include "cpu.h"
#include <inttypes.h>
#include <avr/io.h>
#include <avr/interrupt.h>
#include <avr/pgmspace.h>
#include <avr/eeprom.h>
#include <util/delay.h>
#include <stdbool.h>
#include "main.h"
#include "lcd.h"
#include "usart.h"
#include "uart1.h"
#include "display.h"
#include "timer.h"
#include "eeprom.h"
#include "Wi232.h"
#include "twimaster.h"
#include "uart1.h"
#include "bluetooth.h"
#include "error.h"
#include "connect.h"


volatile uint8_t USBBT;
volatile uint8_t U02SV2;


//--------------------------------------------------------------
void InitHWPorts(void)	// Initialisierung der Hardware für die jeweilige Leiterplattenversion

{
	PORTA |= (1<<PORTA4)|(1<<PORTA5)|(1<<PORTA6)|(1<<PORTA7);	// Enable Pull Up for the 4 keys
	DDRA &= ~(1<<DDA4);											// Eingang: A4 auf Low setzen (Power On)

	DDRB = 0xFF; 												// Alles AusgÃ¤nge

	PORTC |= (1<<PORTC4)|(1<<PORTC7);							// Enable Pull Up for LBO + Summer
	DDRC |= (1<<DDC2)|(1<<DDC3)|(1<<DDC5)|(1<<DDC6)|(1<<DDC7);	// Ausgang: Led2,Rs232Switch,Summer
	DDRC &= ~(1<<DDC4);											// Eingang: LowBat LTC1308

	PORTD |= (1<<PORTD6);										// Wi232-CMD auf High schalten
	DDRD |= (1<<DDD4)|(1<<DDD5)|(1<<DDD6)|(1<<DDD7);			// Ausgang: PiepserTest, Servo, Wi232-CMD und Beleuchtung

	set_V_On();			// Spannung mit T3 halten
	set_D_LIGHT();		// Display einschalten
	_delay_ms(250);

	Timer0_Init ();		// system
//	Timer1_Init ();		// pwm
	Timer2_Init ();		// display

	Display_on = 1;
	USART_Init (UART_BAUD_SELECT(USART_BAUD,F_CPU));
	uart1_init (UART_BAUD_SELECT(USART_BAUD,F_CPU));	// USB
	I2C_Init(1);
	sei ();

	LCD_Init (0);		// muss vor "ReadParameter" stehen
	ReadParameter ();	// Aktuelle Werte aus EEProm auslesen

	OCR2A = LCD_Helligkeit * 2.55;
	LCD_Init (1);
	BeepTime = 200;
	BeepMuster = 0x0080;

	// Power On Delay
	lcd_printp_at (2,2,PSTR("Taste 2 Sekunden"), 0);
	lcd_printp_at (2,3,PSTR("lang festhalten."), 0);
	_delay_ms(1000);

	if (PINA & (1<<PINA7))    // Spannung eingeschaltet lassen
		clr_V_On();

	_delay_ms(100);
	BeepTime = 500;
	BeepMuster = 0x0080;
	get_key_press(KEY_ALL);

	lcd_cls();

	if ((UseWi == true) && (WiIsSet == false))
	{
		InitWi232();    // wenn Wi232 nicht initialisiert ist, dann jetzt tun
	}

	lcd_cls();

	if ((UseBT == true) && (BTIsSet == false))
	{
		bt_init();
		set_USBOn();
	}

	lcd_cls();

	if ((UseWi == true) && (U02SV2 == 0))
	{
		Change_Output(Uart02Wi);    // Verbindung zu Wi232 herstellen
		lcd_printp_at (0, 0, PSTR("Verbindung zum MK ist"), 0);
		lcd_printp_at (0, 1, PSTR("auf Wi232 eingestellt"), 0);
//		lcd_printp_at (4, 1, PSTR("Wi232"), 2);
		_delay_ms(2000);
	}
	else
	{
		Change_Output(Uart02FC);    // Verbindung zu SV" (Kabel) herstellen
		lcd_printp_at (0, 0, PSTR("Verbindung zum MK ist"), 0);
		lcd_printp_at (0, 1, PSTR("auf Kabel eingestellt"), 0);
//		lcd_printp_at (4, 1, PSTR("Kabel"), 2);
		_delay_ms(2000);
	}

	lcd_cls();

}


#endif // HAL_HW3_9_C_
